@@ -11,10 +11,14 @@ export default navbar([
         prefix: "/",
         children: [
           { text: "Install", link: "install.html", icon: "arrow-down" },
-          { text: "Getting Started", link: "tour.html", icon: "life-ring" },
+          { text: "Language Tour", link: "tour.html", icon: "life-ring" },
           { text: "Rosetta Stone", link: "user-guide/rosetta-stone.html", icon: "language" },
           { text: "User Guide", link: "user-guide/", icon: "book" },
+          { text: "Operators And Tokens", link: "parser/", icon: "equals" },
           { text: "Builtins", link: "commands/", icon: "terminal" },
+          { text: "Variables", link: "variables/", icon: "dollar" },
+          { text: "Data Types", link: "types/", icon: "table" },
+          { text: "Events", link: "events/", icon: "bolt" },
         ],
       },
     ],
