@@ -21,10 +21,10 @@ func TestParamHangBug(t *testing.T) {
 			Block:  `out: $FOO{BAR}`,
 			Stdout: "{BAR}\n",
 		},
-		/*{
+		{
 			Block:  `out: $ FOO{BAR}`,
 			Stdout: "$ FOO{BAR}\n",
-		},*/
+		},
 		{
 			Block:  `out: ${out}`,
 			Stdout: "\n",
@@ -37,22 +37,18 @@ func TestParamHangBug(t *testing.T) {
 			Block:  `out: $FOO[BAR]`,
 			Stdout: "\n",
 		},
-		/*{
+		{
 			Block:  `out: $ FOO[BAR]`,
 			Stdout: "$ FOO[BAR]\n",
-		},*/
-		/*{
+		},
+		{
 			Block:  `out: $[out]`,
 			Stdout: "$[out]\n",
-		},*/
+		},
 		{
 			Block:  `out: $FOO(BAR)`,
 			Stdout: "(BAR)\n",
 		},
-		/*{
-			Block:  `out: $ FOO(BAR)`,
-			Stdout: "$ FOO(BAR)\n",
-		},*/
 		{
 			Block:  `out: $(out)`,
 			Stdout: "\n",
@@ -94,10 +90,6 @@ func TestParamHangBug(t *testing.T) {
 			Block:  `out: @FOO(BAR)`,
 			Stdout: "(BAR)\n",
 		},
-		{
-			Block:  `out: @ FOO(BAR)`,
-			Stdout: "@ FOO(BAR)\n",
-		},
 		{
 			Block:  `out: @(out)`,
 			Stdout: "@(out)\n",
