@@ -11,36 +11,6 @@ import (
 //  Schedulers  //
 //////////////////
 
-// `evil` - Only use this if you are not concerned about STDERR nor exit number.
-/*func runModeEvil(procs []Process) int {
-	if len(procs) == 0 {
-		return 1
-	}
-
-	procs[0].Previous.SetTerminatedState(true)
-
-	for i := range procs {
-
-		if i > 0 {
-			if !procs[i].IsMethod {
-				waitProcess(&procs[i-1])
-			} else {
-				go waitProcess(&procs[i-1])
-			}
-		}
-
-		//if procs[i].Name == "break" {
-		//	exitNum, _ := procs[i].Parameters.Int(0)
-		//	return exitNum
-		//}
-		procs[i].Stderr = new(null.Null)
-		go executeProcess(&procs[i])
-	}
-
-	waitProcess(&procs[len(procs)-1])
-	return 0
-}*/
-
 func runModeNormal(procs *[]Process) (exitNum int) {
 	var (
 		prev         int
@@ -86,7 +56,7 @@ func runModeNormal(procs *[]Process) (exitNum int) {
 }
 
 // `try` - Last process in each pipe is checked.
-func runModeTry(procs *[]Process) (exitNum int) {
+func runModeTry(procs *[]Process, tryErr bool) (exitNum int) {
 	if len((*procs)) == 0 {
 		return 1
 	}
@@ -98,11 +68,9 @@ func runModeTry(procs *[]Process) (exitNum int) {
 		if next == len((*procs)) || !(*procs)[next].IsMethod {
 			waitProcess(&(*procs)[i])
 			exitNum = (*procs)[i].ExitNum
-			outSize, _ := (*procs)[i].Stdout.Stats()
-			errSize, _ := (*procs)[i].Stderr.Stats()
 
-			if exitNum < 1 && errSize > outSize {
-				exitNum = 1
+			if tryErr {
+				checkTryErr(&(*procs)[i], &exitNum)
 			}
 
 			if next < len(*procs) {
@@ -138,7 +106,7 @@ func runModeTry(procs *[]Process) (exitNum int) {
 }
 
 // `trypipe` - Each process in the pipeline is tried sequentially. Breaks parallelization.
-func runModeTryPipe(procs *[]Process) (exitNum int) {
+func runModeTryPipe(procs *[]Process, tryPipeErr bool) (exitNum int) {
 	if len(*procs) == 0 {
 		return 1
 	}
@@ -148,11 +116,9 @@ func runModeTryPipe(procs *[]Process) (exitNum int) {
 		waitProcess(&(*procs)[i])
 
 		exitNum = (*procs)[i].ExitNum
-		outSize, _ := (*procs)[i].Stdout.Stats()
-		errSize, _ := (*procs)[i].Stderr.Stats()
 
-		if exitNum == 0 && errSize > outSize {
-			exitNum = 1
+		if tryPipeErr {
+			checkTryErr(&(*procs)[i], &exitNum)
 		}
 
 		next := i + 1
