@@ -12,6 +12,7 @@ import (
 	"github.com/lmorg/murex/lang/stdio"
 	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/utils"
+	"github.com/lmorg/murex/utils/cache"
 	"github.com/lmorg/murex/utils/lists"
 	"github.com/lmorg/murex/utils/parser"
 )
@@ -72,11 +73,20 @@ func matchDynamic(f *Flags, partial string, args dynamicArgs, act *AutoCompleteT
 			params = params[:len(params)-1]
 		}
 
-		cacheHash := dynamicCache.CreateHash(args.exe, params, block)
-		cacheB, cacheDT := dynamicCache.Get(cacheHash)
-		stdout := streams.NewStdin()
+		cacheHash := cache.CreateHash(args.exe, params, block)
+		dc := new(dynamicCacheItemT)
+		ok := cache.Read(cache.AUTOCOMPLETE_DYNAMIC, cacheHash, dc)
+		var stdout stdio.Io
+
+		if ok {
+			stdout = streams.NewStdin()
+			stdout.SetDataType(dc.DataType)
+			_, err := stdout.Write(dc.Stdout)
+			if err != nil {
+				lang.ShellProcess.Stderr.Writeln([]byte("dynamic autocomplete cache error: " + err.Error()))
+			}
+		} else {
 
-		if len(cacheB) == 0 {
 			// Run the commandline if ExecCmdline flag set AND commandline considered safe
 			var fStdin int
 			cmdlineStdout := streams.NewStdin()
@@ -96,7 +106,7 @@ func matchDynamic(f *Flags, partial string, args dynamicArgs, act *AutoCompleteT
 			tee, stdout = streams.NewTee(stdin)
 
 			// Execute the dynamic code block
-			fork = lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_NEW_MODULE | lang.F_BACKGROUND | fStdin | lang.F_CREATE_STDOUT | lang.F_NO_STDERR)
+			fork = lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_NEW_MODULE | lang.F_BACKGROUND | fStdin | lang.F_NO_STDERR)
 			fork.Name.Set(args.exe)
 			fork.Parameters.DefineParsed(params)
 			fork.FileRef = ExesFlagsFileRef[args.exe]
@@ -115,18 +125,13 @@ func matchDynamic(f *Flags, partial string, args dynamicArgs, act *AutoCompleteT
 				lang.ShellProcess.Stderr.Writeln([]byte("dynamic autocomplete returned a none zero exit number." + utils.NewLineString))
 			}
 
-			b, err := tee.ReadAll()
-			if err != nil {
-				lang.ShellProcess.Stderr.Writeln([]byte("dynamic autocomplete cache error: " + err.Error()))
-			}
-			dynamicCache.Set(cacheHash, b, tee.GetDataType(), ExesFlags[args.exe][0].CacheTTL)
-
-		} else {
-			stdout.SetDataType(cacheDT)
-			_, err := stdout.Write(cacheB)
+			dc.DataType = tee.GetDataType()
+			dc.Stdout, err = tee.ReadAll()
 			if err != nil {
 				lang.ShellProcess.Stderr.Writeln([]byte("dynamic autocomplete cache error: " + err.Error()))
 			}
+			ttl := cache.Seconds(ExesFlags[args.exe][0].CacheTTL)
+			cache.Write(cache.AUTOCOMPLETE_DYNAMIC, cacheHash, dc, ttl)
 		}
 
 		select {
