@@ -11,7 +11,6 @@ import (
 	"github.com/lmorg/murex/integrations"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/ref"
-	"github.com/lmorg/murex/lang/tty"
 	"github.com/lmorg/murex/utils"
 	"github.com/lmorg/murex/utils/ansi"
 	"github.com/lmorg/murex/utils/consts"
@@ -52,8 +51,12 @@ func diskSource(filename string) ([]byte, error) {
 }
 
 func execSource(source []rune, sourceRef *ref.Source, exitOnError bool) {
+	if sourceRef == nil {
+		panic("sourceRef is not defined")
+	}
+
 	if debug.Enabled {
-		tty.Stderr.WriteString("Loading profile `" + sourceRef.Module + "`" + utils.NewLineString)
+		os.Stderr.WriteString("Loading profile `" + sourceRef.Module + "`" + utils.NewLineString)
 	}
 
 	var stdin int
@@ -63,9 +66,7 @@ func execSource(source []rune, sourceRef *ref.Source, exitOnError bool) {
 	fork := lang.ShellProcess.Fork(lang.F_PARENT_VARTABLE | stdin)
 	fork.Stdout = new(term.Out)
 	fork.Stderr = term.NewErr(ansi.IsAllowed())
-	if sourceRef != nil {
-		fork.FileRef.Source = sourceRef
-	}
+	fork.FileRef.Source = sourceRef
 	fork.RunMode = lang.ShellProcess.RunMode
 	exitNum, err := fork.Execute(source)
 
@@ -73,7 +74,7 @@ func execSource(source []rune, sourceRef *ref.Source, exitOnError bool) {
 		if exitNum == 0 {
 			exitNum = 1
 		}
-		tty.Stderr.WriteString(err.Error() + utils.NewLineString)
+		os.Stderr.WriteString(err.Error() + utils.NewLineString)
 		lang.Exit(exitNum)
 	}
 
