@@ -4,6 +4,7 @@
 package cache
 
 import (
+	"context"
 	"time"
 
 	"github.com/lmorg/murex/utils/cache/cachedb"
@@ -24,11 +25,19 @@ func Read(namespace string, key string, ptr any) bool {
 	return true
 }
 
+func listDb(ctx context.Context, namespace string) (interface{}, error) {
+	return cachedb.List(ctx, namespace)
+}
+
 func Write(namespace string, key string, value any, ttl time.Time) {
 	write(namespace, key, value, ttl)
 	cachedb.Write(namespace, key, value, ttl)
 }
 
+func trimDb(ctx context.Context, namespace string) ([]string, error) {
+	return cachedb.Trim(ctx, namespace)
+}
+
 func CloseDb() {
 	cachedb.CloseDb()
 }
