@@ -3,13 +3,16 @@
 
 package cache
 
-import "time"
+import (
+	"context"
+	"time"
+)
 
-func SetPath(path string) {
+func SetPath(_ string) {
 	// no nothing
 }
 
-func createDb(namespace string) {
+func createDb(_ string) {
 	// do nothing
 }
 
@@ -17,10 +20,18 @@ func Read(namespace string, key string, ptr any) bool {
 	return read(namespace, key, ptr)
 }
 
+func listDb(_ context.Context, _ string) (interface{}, error) {
+	return nil, nil
+}
+
 func Write(namespace string, key string, value any, ttl time.Time) {
 	write(namespace, key, value, ttl)
 }
 
+func trimDb(_ context.Context, _ string) ([]string, error) {
+	return nil, nil
+}
+
 func CloseDb() {
 	// do nothing
 }
